@@ -31,7 +31,7 @@ from .layout.layout import Layout2D
 from .structures.arrays.one_d.array_1d import Array1D
 from .structures.arrays.two_d.array_2d import Array2D
 from .structures.arrays.values import ValuesIrregular
-from .structures.arrays.abstract_array import ExposureInfo
+from .structures.arrays.abstract_array import Header
 from .structures.grids.one_d.grid_1d import Grid1D
 from .structures.grids.two_d.grid_2d import Grid2D
 from .structures.grids.two_d.grid_2d import Grid2DSparse
@@ -52,4 +52,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = "0.21.1"
+__version__ = "2021.6.07.1"
