@@ -3,7 +3,6 @@ import logging
 import numpy as np
 
 from autoarray import exc
-from autoarray.util import array_util
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
@@ -161,9 +160,9 @@ class AbstractMask(np.ndarray):
         """
         The 1D shape of the masks's sub-grid, which is equivalent to the total number of unmasked pixels in the mask.
         """
-        return int(self.pixels_in_mask * self.sub_size ** 2.0)
+        return int(self.pixels_in_mask * self.sub_size ** self.dimensions)
 
-    def mask_new_sub_size_from_mask(self, mask, sub_size=1) -> "AbstractMask":
+    def mask_new_sub_size_from(self, mask, sub_size=1) -> "AbstractMask":
         """
         Returns the mask on the same scaled coordinate system but with a sub-grid of an input``sub_size`` `.
         """
@@ -173,17 +172,3 @@ class AbstractMask(np.ndarray):
             pixel_scales=self.pixel_scales,
             origin=self.origin,
         )
-
-    def binned_pixel_scales_from_bin_up_factor(self, bin_up_factor: int) -> tuple:
-        """
-        If the mask is binned up to a coarser resolution, computes the ``pixel_scales`` of the binned up mask
-
-        Parameters
-        ----------
-        bin_up_factor : int
-            The factor by which the mask is binned up to a coarser resolution.
-        """
-        if self.pixel_scales is not None:
-            return tuple(
-                pixel_scale * bin_up_factor for pixel_scale in self.pixel_scales
-            )
