@@ -1,13 +1,14 @@
 from autoarray import decorator_util
 import numpy as np
 from autoarray import exc
-from autoarray.structures import arrays
-from autoarray.util import mask_util
+from autoarray.structures.arrays.two_d import array_2d
+from autoarray.mask import mask_2d_util
 
 
 class Convolver:
     def __init__(self, mask, kernel):
-        """ Class to setup the 1D convolution of an / mapping matrix.
+        """
+        Class to setup the 1D convolution of an / mapping matrix.
 
         Take a simple 3x3 and masks:
 
@@ -223,7 +224,7 @@ class Convolver:
                     ].shape[0]
                     mask_1d_index += 1
 
-        self.blurring_mask = mask_util.blurring_mask_2d_from(
+        self.blurring_mask = mask_2d_util.blurring_mask_2d_from(
             mask_2d=mask, kernel_shape_native=kernel.shape_native
         )
 
@@ -305,7 +306,7 @@ class Convolver:
 
         return frame, kernel_frame
 
-    def convolved_image_from_image_and_blurring_image(self, image, blurring_image):
+    def convolve_image(self, image, blurring_image):
         """For a given 1D array and blurring array, convolve the two using this convolver.
 
         Parameters
@@ -323,19 +324,17 @@ class Convolver:
             )
 
         convolved_image = self.convolve_jit(
-            image_1d_array=image.slim_binned,
+            image_1d_array=image.binned.slim,
             image_frame_1d_indexes=self.image_frame_1d_indexes,
             image_frame_1d_kernels=self.image_frame_1d_kernels,
             image_frame_1d_lengths=self.image_frame_1d_lengths,
-            blurring_1d_array=blurring_image.slim_binned,
+            blurring_1d_array=blurring_image.binned.slim,
             blurring_frame_1d_indexes=self.blurring_frame_1d_indexes,
             blurring_frame_1d_kernels=self.blurring_frame_1d_kernels,
             blurring_frame_1d_lengths=self.blurring_frame_1d_lengths,
         )
 
-        return arrays.Array2D(
-            array=convolved_image, mask=self.mask.mask_sub_1, store_slim=True
-        )
+        return array_2d.Array2D(array=convolved_image, mask=self.mask.mask_sub_1)
 
     @staticmethod
     @decorator_util.jit()
