@@ -1,9 +1,12 @@
-from autoarray.util import transformer_util
-from autoarray.structures import arrays, visibilities as vis, grids
-from autoarray.util import array_util
+from autoarray.operators import transformer_util
+from autoarray.structures.arrays.two_d import array_2d
+from autoarray.structures.grids.two_d import grid_2d
+from autoarray.structures import visibilities as vis
+from autoarray.structures.arrays.two_d import array_2d_util
 from astropy import units
-from pynufft import NUFFT_cpu
+from pynufft.linalg.nufft_cpu import NUFFT_cpu
 import pylops
+import warnings
 
 import copy
 import numpy as np
@@ -16,7 +19,7 @@ class TransformerDFT(pylops.LinearOperator):
 
         self.uv_wavelengths = uv_wavelengths.astype("float")
         self.real_space_mask = real_space_mask.mask_sub_1
-        self.grid = self.real_space_mask.masked_grid_sub_1.slim_binned.in_radians
+        self.grid = self.real_space_mask.masked_grid_sub_1.binned.in_radians
 
         self.total_visibilities = uv_wavelengths.shape[0]
         self.total_image_pixels = self.real_space_mask.pixels_in_mask
@@ -47,7 +50,7 @@ class TransformerDFT(pylops.LinearOperator):
         if self.preload_transform:
 
             visibilities = transformer_util.visibilities_via_preload_jit_from(
-                image_1d=image.slim_binned,
+                image_1d=image.binned,
                 preloaded_reals=self.preload_real_transforms,
                 preloaded_imags=self.preload_imag_transforms,
             )
@@ -55,13 +58,32 @@ class TransformerDFT(pylops.LinearOperator):
         else:
 
             visibilities = transformer_util.visibilities_jit(
-                image_1d=image.slim_binned,
+                image_1d=image.binned,
                 grid_radians=self.grid,
                 uv_wavelengths=self.uv_wavelengths,
             )
 
         return vis.Visibilities(visibilities=visibilities)
 
+    def image_from_visibilities(self, visibilities):
+
+        image_slim = transformer_util.image_from_visibilities_jit(
+            n_pixels=self.grid.shape[0],
+            grid_radians=self.grid,
+            uv_wavelengths=self.uv_wavelengths,
+            visibilities=visibilities.in_array,
+        )
+
+        image_native = array_2d_util.array_2d_native_from(
+            array_2d_slim=image_slim,
+            mask_2d=self.real_space_mask,
+            sub_size=self.real_space_mask.sub_size,
+        )
+
+        return array_2d.Array2D.manual_native(
+            array=image_native, pixel_scales=self.real_space_mask.pixel_scales
+        )
+
     def transformed_mapping_matrix_from_mapping_matrix(self, mapping_matrix):
 
         if self.preload_transform:
@@ -89,7 +111,7 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
         self.uv_wavelengths = uv_wavelengths
         self.real_space_mask = real_space_mask.mask_sub_1
         #        self.grid = self.real_space_mask.unmasked_grid.in_radians
-        self.grid = grids.Grid2D.from_mask(mask=self.real_space_mask).in_radians
+        self.grid = grid_2d.Grid2D.from_mask(mask=self.real_space_mask).in_radians
         self._sub_native_index_for_sub_slim_index = copy.copy(
             real_space_mask._sub_native_index_for_sub_slim_index.astype("int")
         )
@@ -164,38 +186,41 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
         ...
         """
 
+        warnings.filterwarnings("ignore")
+
         return vis.Visibilities(
             visibilities=self.forward(
-                image.native_binned[::-1, :]
+                image.binned.native[::-1, :]
             )  # flip due to PyNUFFT internal flip
         )
 
     def image_from_visibilities(self, visibilities):
-        return np.real(self.adjoint(visibilities))
+        image = np.real(self.adjoint(visibilities))
+        return array_2d.Array2D.manual_native(
+            array=image, pixel_scales=self.real_space_mask.pixel_scales
+        )
 
     def transformed_mapping_matrix_from_mapping_matrix(self, mapping_matrix):
 
-        transfomed_mapping_matrix = 0 + 0j * np.zeros(
+        transformed_mapping_matrix = 0 + 0j * np.zeros(
             (self.uv_wavelengths.shape[0], mapping_matrix.shape[1])
         )
 
         for source_pixel_1d_index in range(mapping_matrix.shape[1]):
 
-            image_2d = array_util.sub_array_2d_from(
-                sub_array_2d_slim=mapping_matrix[:, source_pixel_1d_index],
+            image_2d = array_2d_util.array_2d_native_from(
+                array_2d_slim=mapping_matrix[:, source_pixel_1d_index],
                 mask_2d=self.grid.mask,
                 sub_size=1,
             )
 
-            image = arrays.Array2D(
-                array=image_2d, mask=self.grid.mask, store_slim=False
-            )
+            image = array_2d.Array2D(array=image_2d, mask=self.grid.mask)
 
             visibilities = self.visibilities_from_image(image=image)
 
-            transfomed_mapping_matrix[:, source_pixel_1d_index] = visibilities
+            transformed_mapping_matrix[:, source_pixel_1d_index] = visibilities
 
-        return transfomed_mapping_matrix
+        return transformed_mapping_matrix
 
     def forward_lop(self, x):
         """
@@ -206,10 +231,12 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
         :rtype: numpy array with the dtype of numpy.complex64
         """
 
-        x2d = array_util.sub_array_2d_complex_via_sub_indexes_from(
-            sub_array_2d_slim=x,
+        warnings.filterwarnings("ignore")
+
+        x2d = array_2d_util.array_2d_native_complex_via_indexes_from(
+            array_2d_slim=x,
             sub_shape_native=self.real_space_mask.shape_native,
-            sub_native_index_for_slim_index=self._sub_native_index_for_sub_slim_index,
+            native_index_for_slim_index_2d=self._sub_native_index_for_sub_slim_index,
         )[::-1, :]
 
         y = self.k2y(self.xx2k(self.x2xx(x2d)))
@@ -225,6 +252,8 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
         :rtype: numpy array with the dtype of numpy.complex64
         """
 
+        warnings.filterwarnings("ignore")
+
         def a_complex_from_a_real_and_a_imag(a_real, a_imag):
 
             return a_real + 1j * a_imag
@@ -235,8 +264,8 @@ class TransformerNUFFT(NUFFT_cpu, pylops.LinearOperator):
 
         x2d = np.real(self.xx2x(self.k2xx(self.y2k(y))))
 
-        x = array_util.sub_array_complex_slim_from(
-            sub_array_2d=x2d[::-1, :], sub_size=1, mask=self.real_space_mask
+        x = array_2d_util.array_2d_slim_complex_from(
+            array_2d_native=x2d[::-1, :], sub_size=1, mask=self.real_space_mask
         )
         x = x.real  # NOTE:
 
