@@ -1,10 +1,16 @@
 from autoarray.mask import mask_1d
-from autoarray.structures import arrays, grids, lines as l, vector_fields
+from autoarray.structures.arrays.one_d import array_1d
+from autoarray.structures.arrays.two_d import array_2d
+from autoarray.structures.grids.two_d import grid_2d
+from autoarray.structures.grids.two_d import grid_2d_irregular
+from autoarray.structures.vector_fields import vector_field_irregular
 from autoarray.plot.mat_wrap import mat_plot, include as inc
 from autoarray.mask import mask_2d
 from matplotlib import patches as ptch
 import typing
+from typing import Optional
 from abc import ABC
+from typing import List, Union
 
 
 class AbstractVisuals(ABC):
@@ -62,14 +68,14 @@ class AbstractVisuals(ABC):
 class Visuals1D(AbstractVisuals):
     def __init__(
         self,
-        mask: mask_1d.Mask1D = None,
-        lines: typing.List[l.Line1D] = None,
-        origin: grids.Grid2D = None,
+        mask: Optional[mask_1d.Mask1D] = None,
+        origin: Optional[grid_2d.Grid2D] = None,
+        vertical_line: Optional[float] = None,
     ):
 
         self.mask = mask
-        self.lines = lines
         self.origin = origin
+        self.vertical_line = vertical_line
 
     @property
     def plotter(self):
@@ -81,24 +87,28 @@ class Visuals1D(AbstractVisuals):
 
     def plot_via_plotter(self, plotter):
 
-        if self.lines is not None:
-            plotter.grid_plot.plot_grid(grid=self.lines)
+        if self.vertical_line is not None:
+
+            plotter.vertical_line_axvline.axvline_vertical_line(
+                vertical_line=self.vertical_line
+            )
 
 
 class Visuals2D(AbstractVisuals):
-
     def __init__(
         self,
-        origin: grids.Grid2D = None,
+        origin: grid_2d.Grid2D = None,
         mask: mask_2d.Mask2D = None,
-        border: grids.Grid2D = None,
-        lines: typing.List[l.Line1D] = None,
-        positions: grids.Grid2DIrregular = None,
-        grid: grids.Grid2D = None,
-        pixelization_grid: grids.Grid2D = None,
-        vector_field: vector_fields.VectorField2DIrregular = None,
-        patches: typing.List[ptch.Patch] = None,
-        array_overlay: arrays.Array2D = None,
+        border: grid_2d.Grid2D = None,
+        lines: List[array_1d.Array1D] = None,
+        positions: Union[
+            grid_2d_irregular.Grid2DIrregular, List[grid_2d_irregular.Grid2DIrregular]
+        ] = None,
+        grid: grid_2d.Grid2D = None,
+        pixelization_grid: grid_2d.Grid2D = None,
+        vector_field: vector_field_irregular.VectorField2DIrregular = None,
+        patches: List[ptch.Patch] = None,
+        array_overlay: array_2d.Array2D = None,
         parallel_overscan=None,
         serial_prescan=None,
         serial_overscan=None,
@@ -125,12 +135,12 @@ class Visuals2D(AbstractVisuals):
     def plot_via_plotter(self, plotter, grid_indexes=None, mapper=None):
 
         if self.origin is not None:
-            plotter.origin_scatter.scatter_grid(grid=grids.Grid2DIrregular(grid=self.origin))
+            plotter.origin_scatter.scatter_grid(
+                grid=grid_2d_irregular.Grid2DIrregular(grid=self.origin)
+            )
 
         if self.mask is not None:
-            plotter.mask_scatter.scatter_grid(
-                grid=self.mask.edge_grid_sub_1.slim_binned
-            )
+            plotter.mask_scatter.scatter_grid(grid=self.mask.edge_grid_sub_1.binned)
 
         if self.border is not None:
             plotter.border_scatter.scatter_grid(grid=self.border)
