@@ -685,3 +685,33 @@ def numpy_array_2d_from_fits(
     if flip_for_ds9:
         return np.flipud(np.array(hdu_list[hdu].data)).astype("float64")
     return np.array(hdu_list[hdu].data).astype("float64")
+
+
+def header_obj_from_fits(file_path: str, hdu: int):
+    """
+    Read a 2D NumPy array from a .fits file.
+
+    After loading the NumPy array, the array is flipped upside-down using np.flipud. This is so that the structures
+    appear the same orientation as .fits files loaded in DS9.
+
+    Parameters
+    ----------
+    file_path : str
+        The full path of the file that is loaded, including the file name and ``.fits`` extension.
+    hdu : int
+        The HDU extension of the array that is loaded from the .fits file.
+    do_not_scale_image_data : bool
+        If True, the .fits file is not rescaled automatically based on the .fits header info.
+
+    Returns
+    -------
+    ndarray
+        The NumPy array that is loaded from the .fits file.
+
+    Examples
+    --------
+    array_2d = numpy_array_from_fits(file_path='/path/to/file/filename.fits', hdu=0)
+    """
+    hdu_list = fits.open(file_path)
+
+    return hdu_list[hdu].header
