@@ -3,11 +3,9 @@ import logging
 import numpy as np
 import typing
 
-from autoarray.util import grid_util, mask_util
-
 from matplotlib.patches import Ellipse
 from autoarray.structures.arrays import values
-from autoarray.structures import arrays, grids
+from autoarray.structures.grids.two_d import grid_2d_irregular
 
 from autoarray import exc
 
@@ -19,7 +17,7 @@ class VectorField2DIrregular(np.ndarray):
     def __new__(
         cls,
         vectors: np.ndarray or [(float, float)],
-        grid: grids.Grid2DIrregular or list,
+        grid: grid_2d_irregular.Grid2DIrregular or list,
     ):
         """
         A collection of (y,x) vectors which are located on an irregular grid of (y,x) coordinates.
@@ -41,7 +39,7 @@ class VectorField2DIrregular(np.ndarray):
         ----------
         vectors : np.ndarray or [(float, float)]
             The 2D (y,x) vectors on an irregular grid that represent the vector-field.
-        grid : grids.Grid2DIrregular
+        grid : grid_2d_irregular.Grid2DIrregular
             The irregular grid of (y,x) coordinates where each vector is located.
         """
 
@@ -52,7 +50,7 @@ class VectorField2DIrregular(np.ndarray):
             vectors = np.asarray(vectors)
 
         obj = vectors.view(cls)
-        obj.grid = grids.Grid2DIrregular(grid=grid)
+        obj.grid = grid_2d_irregular.Grid2DIrregular(grid=grid)
 
         return obj
 
@@ -90,7 +88,7 @@ class VectorField2DIrregular(np.ndarray):
     @property
     def phis(self) -> values.ValuesIrregular:
         """
-        If we treat this vector field as a set of weak lensing shear measurements, the position angle phi defined
+        If we treat this vector field as a set of weak lensing shear measurements, the position angle defined
         counter clockwise from the positive x-axis of each galaxy ellipticity that each vector corresponds too.
         """
         return values.ValuesIrregular(
@@ -105,8 +103,10 @@ class VectorField2DIrregular(np.ndarray):
         """
 
         return [
-            Ellipse(xy=(x, y), width=semi_major_axis, height=semi_minor_axis, angle=phi)
-            for x, y, semi_major_axis, semi_minor_axis, phi in zip(
+            Ellipse(
+                xy=(x, y), width=semi_major_axis, height=semi_minor_axis, angle=angle
+            )
+            for x, y, semi_major_axis, semi_minor_axis, angle in zip(
                 self.grid[:, 1],
                 self.grid[:, 0],
                 self.semi_major_axes,
@@ -175,5 +175,40 @@ class VectorField2DIrregular(np.ndarray):
             )
 
         return VectorField2DIrregular(
-            vectors=self[mask], grid=grids.Grid2DIrregular(self.grid[mask])
+            vectors=self[mask], grid=grid_2d_irregular.Grid2DIrregular(self.grid[mask])
+        )
+
+    def vectors_within_annulus(
+        self,
+        inner_radius: float,
+        outer_radius: float,
+        centre: typing.Tuple[float, float] = (0.0, 0.0),
+    ) -> "VectorField2DIrregular":
+        """
+        Returns a new `VectorFieldIrregular` object which has had all vectors outside of a circle of input radius
+        around an  input (y,x) centre removed.
+
+        Parameters
+        ----------
+        radius : float
+            The radius of the circle outside of which vectors are removed.
+        centre : float
+            The centre of the circle outside of which vectors are removed.
+
+        Returns
+        -------
+        VectorFieldIrregular
+            The vector field where all vectors outside of the input radius are removed.
+
+        """
+        squared_distances = self.grid.distances_from_coordinate(coordinate=centre)
+        mask = (inner_radius < squared_distances) & (squared_distances < outer_radius)
+
+        if np.all(mask == False):
+            raise exc.VectorFieldException(
+                "The input radius removed all vectors / points on the grid."
+            )
+
+        return VectorField2DIrregular(
+            vectors=self[mask], grid=grid_2d_irregular.Grid2DIrregular(self.grid[mask])
         )
