@@ -71,6 +71,21 @@ class TestAPI:
 
         assert (kernel.native == 2.0 * np.ones((3, 2))).all()
 
+    def test__from_fits__loads_and_stores_header_info(self,):
+        kernel = aa.Kernel2D.from_fits(
+            file_path=path.join(test_data_dir, "3x2_ones.fits"), hdu=0, pixel_scales=1.0
+        )
+
+        assert kernel.header.header_sci_obj["BITPIX"] == -64
+        assert kernel.header.header_hdu_obj["BITPIX"] == -64
+
+        kernel = aa.Kernel2D.from_fits(
+            file_path=path.join(test_data_dir, "3x2_twos.fits"), hdu=0, pixel_scales=1.0
+        )
+
+        assert kernel.header.header_sci_obj["BITPIX"] == -64
+        assert kernel.header.header_hdu_obj["BITPIX"] == -64
+
     def test__no_blur__correct_kernel(self):
         kernel = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
